from tkinter import messagebox
from tkinter import filedialog
from datetime import datetime
from PIL import Image

import Stopwatch_ru
import Stopwatch_en
import Timer

import webbrowser
import datetime
import calendar
import qrcode
import wget
import rich
import time
import os

class Quelert:
    Version = "2.0.1"

class QlBrowser:
    NamesLib = ["Webbrowser", "Wget"]

    def open(url):
        webbrowser.open(url)

    def download(url, pathsave):
        wget.download(url, pathsave)

class QlDateTime:
    NamesLib = ["Datetime", "Calendar"]
    Date = datetime.date.today()

    def Time():
        date_time = datetime.datetime.now()
        current = date_time.time()
        print(current)

    def Calendar(Year, Month):
        november = calendar.month(Year, Month)
        print(november)

class QlWidgets:
    NamesLib = ["Tkinter"]
    Stopwatch_Lang = ["ru", "en"]

    def ERROR(title, message):
        messagebox.showerror(title, message)

    def WARNING(title, message):
        messagebox.showwarning(title, message)

    def INFO(title, message):
        messagebox.showinfo(title, message)

    def OpenDirectory():
        filedialog.askdirectory()

    def OpenNameFile():
        filedialog.askopenfilename()

    def Stopwatch(lang):
        if lang == "ru":
            Stopwatch_ru.stopwatch()

        elif lang == "en":
            Stopwatch_en.stopwatch()

    def Timer(lang):
        if lang == "ru":
            Timer.ru()

        elif lang == "en":
            Timer.en()

    def QrCode(text, namefile):
        img = qrcode.make(text)
        img.save(namefile)

    def ColorMania():
        os.system("CM\\ColorMania.exe")


from tkinter import *
from tkinter import ttk
from datetime import datetime

temp = 0
after_id = ''

def stopwatch():
    root = Tk()
    root.title("Секундомер")
    root.config(bg="#222")
    root.geometry("400x200")
    root.resizable(False, False)

    def tick():
        global temp, after_id
        after_id = root.after(1000, tick)
        f_temp = datetime.fromtimestamp(temp).strftime("%W:%M:%S")
        Sw.configure(text=str(f_temp))
        temp += 1

    def Start():
        btnStart.place_forget()
        btnStop.place(relx=0.5, rely=0.5, anchor=CENTER)
        tick()

    def Stop():
        btnStop.place_forget()
        btnContinue.place(x=115, y=5)
        btnReset.place(x=205, y=5)
        root.after_cancel(after_id)

    def Reset():
        global temp
        temp = 0
        Sw.configure(text="00:00:00")
        btnContinue.place_forget()
        btnReset.place_forget()
        btnStart.place(relx=0.5, rely=0.5, anchor=CENTER)

    def Continue():
        btnContinue.place_forget()
        btnReset.place_forget()
        btnStop.place(relx=0.5, rely=0.5, anchor=CENTER)
        tick()

    Sw = Label(root, text="00:00:00", bg="#222", fg="white", font="Consolas 40 bold")
    Sw.place(relx=0.5, rely=0.4, anchor=CENTER)

    Control = Frame(root, bg="#363636", height=35)
    Control.pack(fill=BOTH, side=BOTTOM)

    btnStart = ttk.Button(Control, text="Старт", command=Start)
    btnStop = ttk.Button(Control, text="Стоп", command=Stop)
    btnReset = ttk.Button(Control, text="Сбросить", command=Reset)
    btnContinue = ttk.Button(Control, text="Продолжить", command=Continue)

    btnStart.place(relx=0.5, rely=0.5, anchor=CENTER)

    root.mainloop()


import setuptools

setuptools.setup(
	name='Quelert2',
	version='2.0.1',
	author='Georgy2008',
	author_email='zadvornow2908@gmail.com',
	description='Ql2',
	packages=['q'],
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.6',
)